## Summary

## data

This endpoint exports the records in different bibliographical formats, which can be useful when the team works with a particular reference manager.

To add an endpoint, run any of the following:

```
colrev data -a colrev.bibliography_export -p zotero
colrev data -a colrev.bibliography_export -p jabref
colrev data -a colrev.bibliography_export -p citavi
colrev data -a colrev.bibliography_export -p BiBTeX
colrev data -a colrev.bibliography_export -p RIS
colrev data -a colrev.bibliography_export -p CSV
colrev data -a colrev.bibliography_export -p EXCEL
```

<!-- ## Links -->
